@@ -1,12 +1,11 @@
 package IPC::System::Options;
 
-our $DATE = '2015-09-29'; # DATE
-our $VERSION = '0.23'; # VERSION
+our $DATE = '2016-01-02'; # DATE
+our $VERSION = '0.24'; # VERSION
 
 use strict;
 use warnings;
 
-use Carp;
 use Proc::ChildError qw(explain_child_error);
 
 my $log;
@@ -22,11 +21,11 @@ sub import {
             no strict 'refs';
             *{"$caller\::$_[$i]"} = \&{"$self\::" . $_[$i]};
         } elsif ($_[$i] =~ /\A-(.+)/) {
-            croak "$_[$i] requires an argument" unless $i < @_-1;
+            die "$_[$i] requires an argument" unless $i < @_-1;
             $Global_Opts{$1} = $_[$i+1];
             $i++;
         } else {
-            croak "$_[$i] is not exported by ".__PACKAGE__;
+            die "$_[$i] is not exported by ".__PACKAGE__;
         }
         $i++;
     }
@@ -209,7 +208,7 @@ sub _system_or_backtick_or_run {
                      (${$opts->{capture_stderr}} // ''). ">>" : ""),
             );
             $log->error($msg) if $opts->{log};
-            croak $msg if $opt_die;
+            die $msg if $opt_die;
         }
     }
 
@@ -249,7 +248,7 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.23 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-09-29.
+This document describes version 0.24 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-01-02.
 
 =head1 SYNOPSIS
 
@@ -434,7 +433,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
